@@ -41,6 +41,7 @@
 
 #include "comgr.h"
 #include "clang/Driver/Driver.h"
+#include "llvm/Support/VirtualFileSystem.h"
 
 namespace COMGR {
 
@@ -72,22 +73,32 @@ class AMDGPUCompiler {
   llvm::StringSaver Saver = Allocator;
   /// Whether we need to disable Clang's device-lib linking.
   bool NoGpuLib = true;
+  bool UseVFS = false;
+
+  llvm::IntrusiveRefCntPtr<llvm::vfs::OverlayFileSystem> OverlayFS;
+  llvm::IntrusiveRefCntPtr<llvm::vfs::InMemoryFileSystem> InMemoryFS;
 
   amd_comgr_status_t createTmpDirs();
   amd_comgr_status_t removeTmpDirs();
-  amd_comgr_status_t processFile(const char *InputFilePath,
+  amd_comgr_status_t processFile(DataObject *Input, const char *InputFilePath,
                                  const char *OutputFilePath);
   /// Process each file in @c InSet individually, placing output in @c OutSet.
   amd_comgr_status_t processFiles(amd_comgr_data_kind_t OutputKind,
                                   const char *OutputSuffix);
+  amd_comgr_status_t processFiles(amd_comgr_data_kind_t OutputKind,
+                                  const char *OutputSuffix, DataSet *InSet);
   amd_comgr_status_t addIncludeFlags();
   amd_comgr_status_t addTargetIdentifierFlags(llvm::StringRef IdentStr,
                                               bool CompilingSrc);
   amd_comgr_status_t addCompilationFlags();
   amd_comgr_status_t addDeviceLibraries();
+  amd_comgr_status_t extractSpirvFlags(DataSet *BcSet);
 
   amd_comgr_status_t executeInProcessDriver(llvm::ArrayRef<const char *> Args);
 
+  amd_comgr_status_t translateSpirvToBitcodeImpl(DataSet *SpirvInSet,
+                                                 DataSet *BcOutSet);
+
 public:
   AMDGPUCompiler(DataAction *ActionInfo, DataSet *InSet, DataSet *OutSet,
                  llvm::raw_ostream &LogS);
@@ -104,6 +115,7 @@ public:
   amd_comgr_status_t linkToRelocatable();
   amd_comgr_status_t linkToExecutable();
   amd_comgr_status_t compileToExecutable();
+  amd_comgr_status_t compileSpirvToRelocatable();
   amd_comgr_status_t translateSpirvToBitcode();
 
   amd_comgr_language_t getLanguage() const { return ActionInfo->Language; }
